A Rejection Sampling Approach to k-means++
===========================================

This project contains an implementation of the rejection sampling based RS-k-means++ algorithm  for performing the k-means++ seeding [AV07]_ . The implementation is compatible with NumPy and scikit-learn. 

Installation
------------

Install from PyPI using ::
  pip install rskpp




.. [AV07] David Arthur and Sergei Vassilvitskii. “k-means++: the advantages of careful seeding”.In: Proceedings of the Eighteenth Annual ACM-SIAM Symposium on Discrete Algorithms.SODA ’07. New Orleans, Louisiana: Society for Industrial and Applied Mathematics, 2007,pp. 1027–1035. isbn: 9780898716245. url: https://theory.stanford.edu/~sergei/papers/kMeansPP-soda.pdf.